@@ -46,7 +46,7 @@ int main(int argc, char *argv[])
     application.setAttribute(Qt::AA_UseHighDpiPixmaps, true);
 #endif
     // The ki18n application domain must be set before we make any i18n() calls.
-    KLocalizedString::setApplicationDomain(binaryName.toUtf8().constData());
+    KLocalizedString::setApplicationDomain("systemsettings");
 
     KAboutData aboutData;
 
